* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Portfolio Assessment Methodologies](https://help.sap.com/docs/leanix/ea/portfolio-assessment-methodologies)
  * Gartner® TIME Framework
